..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.



API Docs
========

.. automodule:: invenio_explicit_acls.ext
   :members:

Models
------

.. automodule:: invenio_explicit_acls.models
   :members:

.. automodule:: invenio_explicit_acls.acls.default_acls
   :members:

.. automodule:: invenio_explicit_acls.acls.elasticsearch_acls
   :members:

.. automodule:: invenio_explicit_acls.acls.id_acls
   :members:

.. automodule:: invenio_explicit_acls.actors.user
   :members:

.. automodule:: invenio_explicit_acls.actors.role
   :members:

Signals
-------

.. automodule:: invenio_explicit_acls.signals
   :members:

Tasks
-----

.. automodule:: invenio_explicit_acls.tasks
   :members:

Permissions
-----------

.. automodule:: invenio_explicit_acls.permissions
   :members:

Serializers
-----------

.. automodule:: invenio_explicit_acls.serializers
   :members:
